==> aroundme_0_7_0.zip: aroundme_0_7_0/aroundme/components/core/template/barnraiser_01/error.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_error'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php 
				if (isset($error_id) && $error_id == 1) {
					echo $lang['txt_no_db_help'];
				}
				else {
					echo $lang['txt_404_help'];
				}
				?><br />
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>
		
<div class="col_side">
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_menu'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($_SESSION['user_homepage'])) {
				?>
				<a href="index.php?amn=core_<?php echo $_SESSION['user_homepage'];?>"><?php echo $lang['href_404_my_home'];?></a><br />
				<?php }?>

				<a href="index.php"><?php echo $lang['href_404_home'];?></a><br />
				<a href="http://www.barnraiser.org/"><?php echo $lang['href_404_barnraiser'];?></a><br />
			</div>
		</div>
	</div>
	
	<div class="box_bottom">
		<span class="box_bottom_right"></span>
		<span class="box_bottom_left"></span>
	</div>
</div>

==> aroundme_0_7_4.zip: aroundme_0_7_4/aroundme/components/core/template/barnraiser_01/error.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

?>

<div class="col_main">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_error'];?><br />
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php 
				if (isset($error_id) && $error_id == 1) {
					echo $lang['txt_no_db_help'];
				}
				else {
					echo $lang['txt_404_help'];
				}
				?><br />
			</div>
		</div>
	</div>
</div>
		
<div class="col_side">
	<div class="box">
		<div class="box_top">
			<div class="content">
				<?php echo $lang['hdr_menu'];?><br />
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($_SESSION['user_homepage'])) {
				?>
				<a href="index.php?amn=<?php echo $_SESSION['user_homepage'];?>"><?php echo $lang['href_404_my_home'];?></a><br />
				<?php }?>

				<a href="index.php"><?php echo $lang['href_404_home'];?></a><br />
				<a href="http://www.barnraiser.org/"><?php echo $lang['href_404_barnraiser'];?></a><br />
			</div>
		</div>
	</div>
</div>
